%global emacs_lispdir %{_datadir}/emacs/site-lisp

#define withpython

%if "%{?withpython}"

%global pythonver %{withpython}
%global pythonname Python-%{withpython}
%global docutilsname docutils-0.11
%global pythonhg python-hg
%global hgpyprefix /usr/%{python-hg}
# byte compilation will fail on some some Python /test/ files
%global _python_bytecompile_errors_terminate_build 0

%else

%global pythonver %(python -c 'import sys;print ".".join(map(str, sys.version_info[:2]))')

%endif

Summary: A fast, lightweight Source Control Management system
Name: mercurial
Version: 3.0
Release: 0.38.rc.06a2a854a936
License: GPLv2+
Group: Development/Tools
URL: http://mercurial.selenic.com/
Source0: http://mercurial.selenic.com/release/%{name}-%{version}.tar.gz
%if "%{?withpython}"
Source1: %{pythonname}.tgz
Source2: %{docutilsname}.tar.gz
%endif
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root

BuildRequires: make, gcc, gettext
%if "%{?withpython}"
BuildRequires: readline-devel, openssl-devel, ncurses-devel, zlib-devel, bzip2-devel
%else
BuildRequires: python >= 2.6, python-devel, python-docutils >= 0.5
Requires: python >= 2.6
%endif
Provides: hg = %{version}-%{release}
# The hgk extension uses the wish tcl interpreter, but we don't enforce it
#Requires: tk

%description
Mercurial is a fast, lightweight source control management system designed
for efficient handling of very large distributed projects.

%prep
%if "%{?withpython}"

%setup -q -a1 -a2

# despite the comments in cgi.py, we do this to prevent rpmdeps from picking /usr/local/bin/python up
sed -i '1c#! /usr/bin/env python' %{pythonname}/Lib/cgi.py

%else

%setup -q

%endif

%build
%if "%{?withpython}"

PYPATH=$PWD/%{pythonname}
cd $PYPATH
./configure --prefix=%{hgpyprefix}
make all %{?_smp_mflags}
cd -

cd %{docutilsname}
LD_LIBRARY_PATH=$PYPATH $PYPATH/python setup.py build
cd -

# verify Python environment
LD_LIBRARY_PATH=$PYPATH PYTHONPATH=$PWD/%{docutilsname} $PYPATH/python -c 'import sys, zlib, bz2, ssl, curses, readline'

export PATH=$PYPATH:$PATH
export LD_LIBRARY_PATH=$PYPATH
export CFLAGS="-L $PYPATH"
export PYTHONPATH=$PWD/%{docutilsname}

%endif

make all

%install
rm -rf $RPM_BUILD_ROOT

%if "%{?withpython}"

PYPATH=$PWD/%{pythonname}
cd $PYPATH
make install DESTDIR=$RPM_BUILD_ROOT
# these .a are not necessary and they are readonly and strip fails - kill them!
rm -f %{buildroot}%{hgpyprefix}/lib/{,python2.*/config}/libpython2.*.a
cd -

cd %{docutilsname}
LD_LIBRARY_PATH=$PYPATH $PYPATH/python setup.py install --root="$RPM_BUILD_ROOT"
cd -

PATH=$PYPATH:$PATH LD_LIBRARY_PATH=$PYPATH make install DESTDIR=$RPM_BUILD_ROOT PREFIX=%{hgpyprefix} MANDIR=%{_mandir}
mkdir -p $RPM_BUILD_ROOT%{_bindir}
( cd $RPM_BUILD_ROOT%{_bindir}/ && ln -s ../..%{hgpyprefix}/bin/hg . )
( cd $RPM_BUILD_ROOT%{_bindir}/ && ln -s ../..%{hgpyprefix}/bin/python2.? %{pythonhg} )

%else

make install DESTDIR=$RPM_BUILD_ROOT PREFIX=%{_prefix} MANDIR=%{_mandir}

%endif

install -m 755 contrib/hgk $RPM_BUILD_ROOT%{_bindir}/
install -m 755 contrib/hg-ssh $RPM_BUILD_ROOT%{_bindir}/

bash_completion_dir=$RPM_BUILD_ROOT%{_sysconfdir}/bash_completion.d
mkdir -p $bash_completion_dir
install -m 644 contrib/bash_completion $bash_completion_dir/mercurial.sh

zsh_completion_dir=$RPM_BUILD_ROOT%{_datadir}/zsh/site-functions
mkdir -p $zsh_completion_dir
install -m 644 contrib/zsh_completion $zsh_completion_dir/_mercurial

mkdir -p $RPM_BUILD_ROOT%{emacs_lispdir}
install -m 644 contrib/mercurial.el $RPM_BUILD_ROOT%{emacs_lispdir}/
install -m 644 contrib/mq.el $RPM_BUILD_ROOT%{emacs_lispdir}/

mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/mercurial/hgrc.d
install -m 644 contrib/mergetools.hgrc $RPM_BUILD_ROOT%{_sysconfdir}/mercurial/hgrc.d/mergetools.rc

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root,-)
%doc CONTRIBUTORS COPYING doc/README doc/hg*.txt doc/hg*.html *.cgi contrib/*.fcgi
%doc %attr(644,root,root) %{_mandir}/man?/hg*
%doc %attr(644,root,root) contrib/*.svg contrib/sample.hgrc
%dir %{_datadir}/zsh/
%dir %{_datadir}/zsh/site-functions/
%{_datadir}/zsh/site-functions/_mercurial
%dir %{_datadir}/emacs/site-lisp/
%{_datadir}/emacs/site-lisp/mercurial.el
%{_datadir}/emacs/site-lisp/mq.el
%{_bindir}/hg
%{_bindir}/hgk
%{_bindir}/hg-ssh
%dir %{_sysconfdir}/bash_completion.d/
%config(noreplace) %{_sysconfdir}/bash_completion.d/mercurial.sh
%dir %{_sysconfdir}/mercurial
%dir %{_sysconfdir}/mercurial/hgrc.d
%config(noreplace) %{_sysconfdir}/mercurial/hgrc.d/mergetools.rc
%if "%{?withpython}"
%{_bindir}/%{pythonhg}
%{hgpyprefix}
%else
%{_libdir}/python%{pythonver}/site-packages/%{name}-*-py%{pythonver}.egg-info
%{_libdir}/python%{pythonver}/site-packages/%{name}
%{_libdir}/python%{pythonver}/site-packages/hgext
%endif

%changelog
* Mon Apr 28 2014 Mads Kiilerich <madski@unity3d.com> 3.0-0.38.rc.06a2a854a936
- contrib: build rpms that includes Python 2.7 if the platform don't have it

* Sun Apr 27 2014 Mads Kiilerich <madski@unity3d.com> 3.0-0.30.rc.f5f15bc83faf
- merge: change priority / ordering of merge actions

* Sun Apr 27 2014 Mads Kiilerich <madski@unity3d.com> 3.0-0.31.rc.5ef9a163f5f4
- merge: move constant assignments a bit and use them more

* Sun Apr 27 2014 Mads Kiilerich <madski@unity3d.com> 3.0-0.33.rc.d5c2341b1f3d
- merge: separate worker functions for batch remove and batch get

* Sun Apr 27 2014 Mads Kiilerich <madski@unity3d.com> 3.0-0.35.rc.9e8a77cb4b77
- merge: fix stupid indentation left over from previous refactorings

* Sun Apr 27 2014 Mads Kiilerich <madski@unity3d.com> 3.0-0.37.rc.feb53554cf4e
- contrib: improvements to rpm building

* Wed Apr 23 2014 Mads Kiilerich <madski@unity3d.com> 3.0-0.28.rc.d36440d84328
- httppeer: reintroduce _abort that accidentally was removed in 167047ba3cfa

* Tue Apr 22 2014 Pierre-Yves David <pierre-yves.david@fb.com> 3.0-0.22.rc.08c84fd99aac
- bundle2: catch UnknownPartError during local push

* Tue Apr 22 2014 Pierre-Yves David <pierre-yves.david@fb.com> 3.0-0.16.rc.70fcb0a71445
- bundle2: decorate exception raised during bundle processing

* Tue Apr 22 2014 Wagner Bruna <wbruna@softwareexpress.com.br> 3.0-0.15.rc.dae36d3e1c60
- histedit, i18n: replace '+' with concatenation to make hggettext happy

* Tue Apr 22 2014 Wagner Bruna <wbruna@softwareexpress.com.br> 3.0-0.14.rc.7991df9d2f20
- commands: fix typo in --graph description

* Tue Apr 22 2014 Wagner Bruna <wbruna@softwareexpress.com.br> 3.0-0.13.rc.d4daebb21cf6
- revset, i18n: add translator comment to "only"

* Tue Apr 22 2014 Pierre-Yves David <pierre-yves.david@fb.com> 3.0-0.25.rc.5b3717e1a3ea
- bundle2: add an error message to push race error

* Tue Apr 22 2014 Pierre-Yves David <pierre-yves.david@fb.com> 3.0-0.21.rc.a92619a2dbd7
- bundle2: catch UnknownPartError during pull

* Tue Apr 22 2014 Pierre-Yves David <pierre-yves.david@fb.com> 3.0-0.20.rc.b056777221bf
- bundle2: catch UnknownPartError during push

* Tue Apr 22 2014 Pierre-Yves David <pierre-yves.david@fb.com> 3.0-0.19.rc.372f4772f7a0
- bundle2: use a more specific UnknownPartError when no handler is found

* Tue Apr 22 2014 Pierre-Yves David <pierre-yves.david@fb.com> 3.0-0.24.rc.28d76afa1568
- bundle2: fix raising errors during heads checking

* Tue Apr 22 2014 Pierre-Yves David <pierre-yves.david@fb.com> 3.0-0.26.rc.9f3652e851f8
- bundle2: gracefully handle PushRaced error during unbundle

* Tue Apr 22 2014 Mads Kiilerich <madski@unity3d.com> 3.0-0.32.rc.ab6d18b2b99a
- merge: change debug logging and progress

* Tue Apr 22 2014 Mads Kiilerich <madski@unity3d.com> 3.0-0.29.rc.c74273976b4e
- merge: improve debug messages for bid merge

* Tue Apr 22 2014 Pierre-Yves David <pierre-yves.david@fb.com> 3.0-0.27.rc.bcfd44abad93
- bundle2: gracefully handle hook abort

* Tue Apr 22 2014 Pierre-Yves David <pierre-yves.david@fb.com> 3.0-0.23.rc.4345274adc4b
- bundle2: gracefully handle UnknownPartError during unbundle

* Tue Apr 22 2014 Pierre-Yves David <pierre-yves.david@fb.com> 3.0-0.18.rc.9a813e703172
- bundle2: make error testing more modular

* Tue Apr 22 2014 Pierre-Yves David <pierre-yves.david@fb.com> 3.0-0.17.rc.952af771bc17
- bundle2: gracefully handle abort during unbundle

* Mon Apr 21 2014 Matt Mackall <mpm@selenic.com> 3.0-0.7.rc.1ce131b3221e
- merge: fix test failures with new merge code on OS X

* Mon Apr 21 2014 Mads Kiilerich <madski@unity3d.com> 3.0-0.12.rc.0f0059af920c
- merge: improve notes for listing the bids for ambiguous merges

* Mon Apr 21 2014 Mads Kiilerich <madski@unity3d.com> 3.0-0.10.rc.ea3972243320
- merge: fix stray character in bid merge message

* Mon Apr 21 2014 Mads Kiilerich <madski@unity3d.com> 3.0-0.9.rc.b743077db69a
- tests: better test coverage for bid merge

* Mon Apr 21 2014 Mads Kiilerich <madski@unity3d.com> 3.0-0.8.rc.355058ad8405
- merge: fix wrong number of arguments for bid merge message

* Sat Apr 19 2014 Martin Geisler <martin@geisler.net> 3.0-0.6.rc.bf2891877378
- obsolete: fix one-element tuple in module docstring

* Sat Apr 19 2014 Martin Geisler <martin@geisler.net> 3.0-0.5.rc.fde46c534935
- obsolete: let N denote number of obsoleted changestes in a marker

* Sat Apr 19 2014 Martin Geisler <martin@geisler.net> 3.0-0.4.rc.2efcef493aa2
- obsolete: fix language and grammar in module docstring

* Sat Apr 19 2014 Isaac Jurado <diptongo@gmail.com> 3.0-0.3.rc.9846b40d01e7
- churn: compute padding with unicode strings

* Fri Apr 18 2014 Mads Kiilerich <madski@unity3d.com> 3.0-0.11.rc.33737ebc6f39
- merge: tell the user when we are using bid merge

* Fri Apr 18 2014 Matt Mackall <mpm@selenic.com> 3.0-0.2.rc.d924e387604f
- Added signature for changeset 564f55b25122

* Fri Apr 18 2014 Matt Mackall <mpm@selenic.com> 3.0-0.1.rc.ef59019f4771
- Added tag 3.0-rc for changeset 564f55b25122

* Fri Apr 18 2014 Matt Mackall <mpm@selenic.com> 3.0-0.0.rc.564f55b25122
- merge default into stable for 3.0 code freeze

* Fri Feb 28 2014 Mads Kiilerich <madski@unity3d.com> 3.0-0.34.rc.c6d057c137b5
- merge: use separate lists for each action type

* Sun May 13 2012 Mads Kiilerich <mads@kiilerich.com> 3.0-0.36.rc.75040d393e38
- merge: simplify mergestate iter

